@@ -9,6 +9,11 @@
 #include "strtonum.h"
 #endif
 
+/* Use CLOCK_REALTIME if CLOCK_MONOTONIC is not available */
+#ifndef CLOCK_MONOTONIC
+#define CLOCK_MONOTONIC CLOCK_REALTIME
+#endif
+
 #ifndef timespecsub
 #define	timespecsub(tsp, usp, vsp)					\
 	do {								\
